@@ -1,13 +1,13 @@
 /**
 Macros used in the library.
 
-\file config.h
+\file
 \copyright Copyright 2020. Tom de Geus. All rights reserved.
 \license This project is released under the MIT License.
 */
 
-#ifndef GMATTENSOR_H
-#define GMATTENSOR_H
+#ifndef GMATTENSOR_CONFIG_H
+#define GMATTENSOR_CONFIG_H
 
 #include <string>
 #include <algorithm>
@@ -51,4 +51,9 @@ The advantage is that:
 #define GMATTENSOR_ASSERT(expr)
 #endif
 
+/**
+Tensor products / operations.
+*/
+namespace GMatTensor { }
+
 #endif
